@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 """
 Display number of unread messages from IMAP account.
 
@@ -63,19 +62,19 @@ SAMPLE OUTPUT
 {'full_text': 'Mail: 36', 'color': '#00FF00'}
 """
 import imaplib
-import os
+from pathlib import Path
+from socket import error as socket_error
+from socket import setdefaulttimeout
+from ssl import create_default_context
 from threading import Thread
 from time import sleep
-from ssl import create_default_context
-from socket import setdefaulttimeout, error as socket_error
 
 STRING_UNAVAILABLE = "N/A"
 NO_DATA_YET = -1
 
 
 class Py3status:
-    """
-    """
+    """"""
 
     # available configuration parameters
     allow_urgent = False
@@ -119,14 +118,12 @@ class Py3status:
         self.connection = None
         self.mail_error = None  # cannot throw self.py3.error from thread
         self.network_error = None
-        self.command_tag = (
-            0  # IMAPcommands are tagged, so responses can be matched up to requests
-        )
+        self.command_tag = 0  # IMAPcommands are tagged, so responses can be matched up to requests
         self.idle_thread = Thread()
 
         if self.client_secret:
-            self.client_secret = os.path.expanduser(self.client_secret)
-        self.auth_token = os.path.expanduser(self.auth_token)
+            self.client_secret = Path(self.client_secret).expanduser()
+        self.auth_token = Path(self.auth_token).expanduser()
 
         if self.security not in ["ssl", "starttls"]:
             raise ValueError("Unknown security protocol")
@@ -135,9 +132,7 @@ class Py3status:
         # I -- acquire mail_count
         if self.use_idle is not False:
             if not self.idle_thread.is_alive():
-                sleep(
-                    self.read_timeout
-                )  # rate-limit thread-restarting (when network is offline)
+                sleep(self.read_timeout)  # rate-limit thread-restarting (when network is offline)
                 self.idle_thread = Thread(target=self._get_mail_count)
                 self.idle_thread.daemon = True
                 self.idle_thread.start()
@@ -150,9 +145,7 @@ class Py3status:
             self.mail_error = None
 
         # II -- format response
-        response["full_text"] = self.py3.safe_format(
-            self.format, {"unseen": self.mail_count}
-        )
+        response["full_text"] = self.py3.safe_format(self.format, {"unseen": self.mail_count})
 
         if self.mail_count is None:
             response["color"] = (self.py3.COLOR_BAD,)
@@ -180,16 +173,17 @@ class Py3status:
             self.py3.error("Server does not support IDLE")
 
     def _get_creds(self):
-        from google_auth_oauthlib.flow import InstalledAppFlow
-        from google.auth.transport.requests import Request
-        from google.auth.exceptions import TransportError
         import pickle
 
+        from google.auth.exceptions import TransportError
+        from google.auth.transport.requests import Request
+        from google_auth_oauthlib.flow import InstalledAppFlow
+
         self.creds = None
 
         # Open pickle file with access and refresh tokens if it exists
-        if os.path.exists(self.auth_token):
-            with open(self.auth_token, "rb") as token:
+        if self.auth_token.exists():
+            with self.auth_token.open("rb") as token:
                 self.creds = pickle.load(token)
 
         if not self.creds or not self.creds.valid:
@@ -204,7 +198,7 @@ class Py3status:
                     )
                     self.creds = flow.run_local_server(port=0)
                 # Save the credentials for the next run
-                with open(self.auth_token, "wb") as token:
+                with self.auth_token.open("wb") as token:
                     pickle.dump(self.creds, token)
             except TransportError as e:
                 # Treat the same as a socket_error
@@ -272,9 +266,7 @@ class Py3status:
             # Dovecot will responde with "+ idling", courier will return "+ entering idle mode"
             # RFC 2177 (https://tools.ietf.org/html/rfc2177) only requires the "+" character.
             if not response.lower().startswith("+"):
-                raise imaplib.IMAP4.abort(
-                    "While initializing IDLE: {}".format(response)
-                )
+                raise imaplib.IMAP4.abort(f"While initializing IDLE: {response}")
 
             # wait for changes (EXISTS, EXPUNGE, etc.):
             socket.settimeout(self.cache_timeout)
@@ -304,9 +296,7 @@ class Py3status:
                 try:
                     response = socket.read(4096).decode("ascii")
                 except socket_error:
-                    raise imaplib.IMAP4.abort(
-                        "Server sent more continuations, but no 'DONE' ack"
-                    )
+                    raise imaplib.IMAP4.abort("Server sent more continuations, but no 'DONE' ack")
 
             expected_response = (command_tag + b" OK").decode("ascii")
             if not response.lower().startswith(expected_response.lower()):
@@ -360,7 +350,7 @@ class Py3status:
 
                 if self.debug:
                     self.py3.log(
-                        "{} error - {}".format(error_type, e),
+                        f"{error_type} error - {e}",
                         level=self.py3.LOG_WARNING,
                     )
                 self._disconnect()
@@ -369,13 +359,13 @@ class Py3status:
                 if retry_counter <= retry_max:
                     if self.debug:
                         self.py3.log(
-                            "Retrying ({}/{})".format(retry_counter, retry_max),
+                            f"Retrying ({retry_counter}/{retry_max})",
                             level=self.py3.LOG_INFO,
                         )
                     continue
                 break
             except (imaplib.IMAP4.error, Exception) as e:
-                self.mail_error = "Fatal error - {}".format(e)
+                self.mail_error = f"Fatal error - {e}"
                 self._disconnect()
                 self.mail_count = None
 
@@ -383,9 +373,7 @@ class Py3status:
                 if retry_counter <= retry_max:
                     if self.debug:
                         self.py3.log(
-                            "Will retry after 60 seconds ({}/{})".format(
-                                retry_counter, retry_max
-                            ),
+                            "Will retry after 60 seconds ({}/{})".format(retry_counter, retry_max),
                             level=self.py3.LOG_INFO,
                         )
                     sleep(60)
